@@ -15,8 +15,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from decimal import Decimal
-from typing import Any, Dict, Mapping, Sequence, Set, Type, Union, overload
+from typing import Any, Dict, Mapping, Sequence, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -42,6 +41,7 @@ from .paginator import (
 )
 from .type_defs import (
     AttributeDefinitionTypeDef,
+    AttributeValueTypeDef,
     AttributeValueUpdateTypeDef,
     AutoScalingSettingsUpdateTypeDef,
     BatchExecuteStatementOutputTypeDef,
@@ -67,6 +67,7 @@ from .type_defs import (
     DescribeTableOutputTypeDef,
     DescribeTableReplicaAutoScalingOutputTypeDef,
     DescribeTimeToLiveOutputTypeDef,
+    EmptyResponseMetadataTypeDef,
     ExecuteStatementOutputTypeDef,
     ExecuteTransactionOutputTypeDef,
     ExpectedAttributeValueTypeDef,
@@ -189,7 +190,7 @@ class DynamoDBClient(BaseClient):
     def batch_execute_statement(
         self,
         *,
-        Statements: Sequence["BatchStatementRequestTypeDef"],
+        Statements: Sequence[BatchStatementRequestTypeDef],
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...
     ) -> BatchExecuteStatementOutputTypeDef:
         """
@@ -203,7 +204,7 @@ class DynamoDBClient(BaseClient):
     def batch_get_item(
         self,
         *,
-        RequestItems: Mapping[str, "KeysAndAttributesTypeDef"],
+        RequestItems: Mapping[str, KeysAndAttributesTypeDef],
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...
     ) -> BatchGetItemOutputTypeDef:
         """
@@ -217,7 +218,7 @@ class DynamoDBClient(BaseClient):
     def batch_write_item(
         self,
         *,
-        RequestItems: Mapping[str, Sequence["WriteRequestTypeDef"]],
+        RequestItems: Mapping[str, Sequence[WriteRequestTypeDef]],
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...
     ) -> BatchWriteItemOutputTypeDef:
@@ -237,6 +238,14 @@ class DynamoDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#close)
+        """
+
     def create_backup(self, *, TableName: str, BackupName: str) -> CreateBackupOutputTypeDef:
         """
         Creates a backup for an existing table.
@@ -246,7 +255,7 @@ class DynamoDBClient(BaseClient):
         """
 
     def create_global_table(
-        self, *, GlobalTableName: str, ReplicationGroup: Sequence["ReplicaTypeDef"]
+        self, *, GlobalTableName: str, ReplicationGroup: Sequence[ReplicaTypeDef]
     ) -> CreateGlobalTableOutputTypeDef:
         """
         Creates a global table from an existing table.
@@ -258,16 +267,16 @@ class DynamoDBClient(BaseClient):
     def create_table(
         self,
         *,
-        AttributeDefinitions: Sequence["AttributeDefinitionTypeDef"],
+        AttributeDefinitions: Sequence[AttributeDefinitionTypeDef],
         TableName: str,
-        KeySchema: Sequence["KeySchemaElementTypeDef"],
-        LocalSecondaryIndexes: Sequence["LocalSecondaryIndexTypeDef"] = ...,
-        GlobalSecondaryIndexes: Sequence["GlobalSecondaryIndexTypeDef"] = ...,
+        KeySchema: Sequence[KeySchemaElementTypeDef],
+        LocalSecondaryIndexes: Sequence[LocalSecondaryIndexTypeDef] = ...,
+        GlobalSecondaryIndexes: Sequence[GlobalSecondaryIndexTypeDef] = ...,
         BillingMode: BillingModeType = ...,
-        ProvisionedThroughput: "ProvisionedThroughputTypeDef" = ...,
-        StreamSpecification: "StreamSpecificationTypeDef" = ...,
-        SSESpecification: "SSESpecificationTypeDef" = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        ProvisionedThroughput: ProvisionedThroughputTypeDef = ...,
+        StreamSpecification: StreamSpecificationTypeDef = ...,
+        SSESpecification: SSESpecificationTypeDef = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         TableClass: TableClassType = ...
     ) -> CreateTableOutputTypeDef:
         """
@@ -289,51 +298,15 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        Key: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ],
-        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = ...,
+        Key: Mapping[str, AttributeValueTypeDef],
+        Expected: Mapping[str, ExpectedAttributeValueTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ReturnValues: ReturnValueType = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
         ConditionExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...
+        ExpressionAttributeValues: Mapping[str, AttributeValueTypeDef] = ...
     ) -> DeleteItemOutputTypeDef:
         """
         Deletes a single item in a table by primary key.
@@ -486,24 +459,7 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         Statement: str,
-        Parameters: Sequence[
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ]
-        ] = ...,
+        Parameters: Sequence[AttributeValueTypeDef] = ...,
         ConsistentRead: bool = ...,
         NextToken: str = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
@@ -520,7 +476,7 @@ class DynamoDBClient(BaseClient):
     def execute_transaction(
         self,
         *,
-        TransactStatements: Sequence["ParameterizedStatementTypeDef"],
+        TransactStatements: Sequence[ParameterizedStatementTypeDef],
         ClientRequestToken: str = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...
     ) -> ExecuteTransactionOutputTypeDef:
@@ -570,25 +526,7 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        Key: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ],
+        Key: Mapping[str, AttributeValueTypeDef],
         AttributesToGet: Sequence[str] = ...,
         ConsistentRead: bool = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
@@ -676,51 +614,15 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        Item: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ],
-        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = ...,
+        Item: Mapping[str, AttributeValueTypeDef],
+        Expected: Mapping[str, ExpectedAttributeValueTypeDef] = ...,
         ReturnValues: ReturnValueType = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ConditionExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...
+        ExpressionAttributeValues: Mapping[str, AttributeValueTypeDef] = ...
     ) -> PutItemOutputTypeDef:
         """
         Creates a new item, or replaces an old item with a new item.
@@ -738,53 +640,17 @@ class DynamoDBClient(BaseClient):
         AttributesToGet: Sequence[str] = ...,
         Limit: int = ...,
         ConsistentRead: bool = ...,
-        KeyConditions: Mapping[str, "ConditionTypeDef"] = ...,
-        QueryFilter: Mapping[str, "ConditionTypeDef"] = ...,
+        KeyConditions: Mapping[str, ConditionTypeDef] = ...,
+        QueryFilter: Mapping[str, ConditionTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ScanIndexForward: bool = ...,
-        ExclusiveStartKey: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...,
+        ExclusiveStartKey: Mapping[str, AttributeValueTypeDef] = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ProjectionExpression: str = ...,
         FilterExpression: str = ...,
         KeyConditionExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...
+        ExpressionAttributeValues: Mapping[str, AttributeValueTypeDef] = ...
     ) -> QueryOutputTypeDef:
         """
         You must provide the name of the partition key attribute and a single value for
@@ -800,10 +666,10 @@ class DynamoDBClient(BaseClient):
         TargetTableName: str,
         BackupArn: str,
         BillingModeOverride: BillingModeType = ...,
-        GlobalSecondaryIndexOverride: Sequence["GlobalSecondaryIndexTypeDef"] = ...,
-        LocalSecondaryIndexOverride: Sequence["LocalSecondaryIndexTypeDef"] = ...,
-        ProvisionedThroughputOverride: "ProvisionedThroughputTypeDef" = ...,
-        SSESpecificationOverride: "SSESpecificationTypeDef" = ...
+        GlobalSecondaryIndexOverride: Sequence[GlobalSecondaryIndexTypeDef] = ...,
+        LocalSecondaryIndexOverride: Sequence[LocalSecondaryIndexTypeDef] = ...,
+        ProvisionedThroughputOverride: ProvisionedThroughputTypeDef = ...,
+        SSESpecificationOverride: SSESpecificationTypeDef = ...
     ) -> RestoreTableFromBackupOutputTypeDef:
         """
         Creates a new table from an existing backup.
@@ -821,10 +687,10 @@ class DynamoDBClient(BaseClient):
         UseLatestRestorableTime: bool = ...,
         RestoreDateTime: Union[datetime, str] = ...,
         BillingModeOverride: BillingModeType = ...,
-        GlobalSecondaryIndexOverride: Sequence["GlobalSecondaryIndexTypeDef"] = ...,
-        LocalSecondaryIndexOverride: Sequence["LocalSecondaryIndexTypeDef"] = ...,
-        ProvisionedThroughputOverride: "ProvisionedThroughputTypeDef" = ...,
-        SSESpecificationOverride: "SSESpecificationTypeDef" = ...
+        GlobalSecondaryIndexOverride: Sequence[GlobalSecondaryIndexTypeDef] = ...,
+        LocalSecondaryIndexOverride: Sequence[LocalSecondaryIndexTypeDef] = ...,
+        ProvisionedThroughputOverride: ProvisionedThroughputTypeDef = ...,
+        SSESpecificationOverride: SSESpecificationTypeDef = ...
     ) -> RestoreTableToPointInTimeOutputTypeDef:
         """
         Restores the specified table to the specified point in time within
@@ -842,52 +708,16 @@ class DynamoDBClient(BaseClient):
         AttributesToGet: Sequence[str] = ...,
         Limit: int = ...,
         Select: SelectType = ...,
-        ScanFilter: Mapping[str, "ConditionTypeDef"] = ...,
+        ScanFilter: Mapping[str, ConditionTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
-        ExclusiveStartKey: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...,
+        ExclusiveStartKey: Mapping[str, AttributeValueTypeDef] = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         TotalSegments: int = ...,
         Segment: int = ...,
         ProjectionExpression: str = ...,
         FilterExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...,
+        ExpressionAttributeValues: Mapping[str, AttributeValueTypeDef] = ...,
         ConsistentRead: bool = ...
     ) -> ScanOutputTypeDef:
         """
@@ -898,7 +728,9 @@ class DynamoDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#scan)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: Sequence["TagTypeDef"]) -> None:
+    def tag_resource(
+        self, *, ResourceArn: str, Tags: Sequence[TagTypeDef]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Associate a set of tags with an Amazon DynamoDB resource.
 
@@ -909,7 +741,7 @@ class DynamoDBClient(BaseClient):
     def transact_get_items(
         self,
         *,
-        TransactItems: Sequence["TransactGetItemTypeDef"],
+        TransactItems: Sequence[TransactGetItemTypeDef],
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...
     ) -> TransactGetItemsOutputTypeDef:
         """
@@ -924,7 +756,7 @@ class DynamoDBClient(BaseClient):
     def transact_write_items(
         self,
         *,
-        TransactItems: Sequence["TransactWriteItemTypeDef"],
+        TransactItems: Sequence[TransactWriteItemTypeDef],
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
         ClientRequestToken: str = ...
@@ -937,7 +769,9 @@ class DynamoDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#transact_write_items)
         """
 
-    def untag_resource(self, *, ResourceArn: str, TagKeys: Sequence[str]) -> None:
+    def untag_resource(
+        self, *, ResourceArn: str, TagKeys: Sequence[str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Removes the association of tags from an Amazon DynamoDB resource.
 
@@ -949,7 +783,7 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        PointInTimeRecoverySpecification: "PointInTimeRecoverySpecificationTypeDef"
+        PointInTimeRecoverySpecification: PointInTimeRecoverySpecificationTypeDef
     ) -> UpdateContinuousBackupsOutputTypeDef:
         """
         `UpdateContinuousBackups` enables or disables point in time recovery for the
@@ -974,7 +808,7 @@ class DynamoDBClient(BaseClient):
         """
 
     def update_global_table(
-        self, *, GlobalTableName: str, ReplicaUpdates: Sequence["ReplicaUpdateTypeDef"]
+        self, *, GlobalTableName: str, ReplicaUpdates: Sequence[ReplicaUpdateTypeDef]
     ) -> UpdateGlobalTableOutputTypeDef:
         """
         Adds or removes replicas in the specified global table.
@@ -989,11 +823,11 @@ class DynamoDBClient(BaseClient):
         GlobalTableName: str,
         GlobalTableBillingMode: BillingModeType = ...,
         GlobalTableProvisionedWriteCapacityUnits: int = ...,
-        GlobalTableProvisionedWriteCapacityAutoScalingSettingsUpdate: "AutoScalingSettingsUpdateTypeDef" = ...,
+        GlobalTableProvisionedWriteCapacityAutoScalingSettingsUpdate: AutoScalingSettingsUpdateTypeDef = ...,
         GlobalTableGlobalSecondaryIndexSettingsUpdate: Sequence[
-            "GlobalTableGlobalSecondaryIndexSettingsUpdateTypeDef"
+            GlobalTableGlobalSecondaryIndexSettingsUpdateTypeDef
         ] = ...,
-        ReplicaSettingsUpdate: Sequence["ReplicaSettingsUpdateTypeDef"] = ...
+        ReplicaSettingsUpdate: Sequence[ReplicaSettingsUpdateTypeDef] = ...
     ) -> UpdateGlobalTableSettingsOutputTypeDef:
         """
         Updates settings for a global table.
@@ -1006,27 +840,9 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        Key: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ],
-        AttributeUpdates: Mapping[str, "AttributeValueUpdateTypeDef"] = ...,
-        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = ...,
+        Key: Mapping[str, AttributeValueTypeDef],
+        AttributeUpdates: Mapping[str, AttributeValueUpdateTypeDef] = ...,
+        Expected: Mapping[str, ExpectedAttributeValueTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ReturnValues: ReturnValueType = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
@@ -1034,25 +850,7 @@ class DynamoDBClient(BaseClient):
         UpdateExpression: str = ...,
         ConditionExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...
+        ExpressionAttributeValues: Mapping[str, AttributeValueTypeDef] = ...
     ) -> UpdateItemOutputTypeDef:
         """
         Edits an existing item's attributes, or adds a new item to the table if it does
@@ -1066,13 +864,13 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        AttributeDefinitions: Sequence["AttributeDefinitionTypeDef"] = ...,
+        AttributeDefinitions: Sequence[AttributeDefinitionTypeDef] = ...,
         BillingMode: BillingModeType = ...,
-        ProvisionedThroughput: "ProvisionedThroughputTypeDef" = ...,
-        GlobalSecondaryIndexUpdates: Sequence["GlobalSecondaryIndexUpdateTypeDef"] = ...,
-        StreamSpecification: "StreamSpecificationTypeDef" = ...,
-        SSESpecification: "SSESpecificationTypeDef" = ...,
-        ReplicaUpdates: Sequence["ReplicationGroupUpdateTypeDef"] = ...,
+        ProvisionedThroughput: ProvisionedThroughputTypeDef = ...,
+        GlobalSecondaryIndexUpdates: Sequence[GlobalSecondaryIndexUpdateTypeDef] = ...,
+        StreamSpecification: StreamSpecificationTypeDef = ...,
+        SSESpecification: SSESpecificationTypeDef = ...,
+        ReplicaUpdates: Sequence[ReplicationGroupUpdateTypeDef] = ...,
         TableClass: TableClassType = ...
     ) -> UpdateTableOutputTypeDef:
         """
@@ -1087,9 +885,9 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        GlobalSecondaryIndexUpdates: Sequence["GlobalSecondaryIndexAutoScalingUpdateTypeDef"] = ...,
-        ProvisionedWriteCapacityAutoScalingUpdate: "AutoScalingSettingsUpdateTypeDef" = ...,
-        ReplicaUpdates: Sequence["ReplicaAutoScalingUpdateTypeDef"] = ...
+        GlobalSecondaryIndexUpdates: Sequence[GlobalSecondaryIndexAutoScalingUpdateTypeDef] = ...,
+        ProvisionedWriteCapacityAutoScalingUpdate: AutoScalingSettingsUpdateTypeDef = ...,
+        ReplicaUpdates: Sequence[ReplicaAutoScalingUpdateTypeDef] = ...
     ) -> UpdateTableReplicaAutoScalingOutputTypeDef:
         """
         Updates auto scaling settings on your global tables at once.
@@ -1099,7 +897,7 @@ class DynamoDBClient(BaseClient):
         """
 
     def update_time_to_live(
-        self, *, TableName: str, TimeToLiveSpecification: "TimeToLiveSpecificationTypeDef"
+        self, *, TableName: str, TimeToLiveSpecification: TimeToLiveSpecificationTypeDef
     ) -> UpdateTimeToLiveOutputTypeDef:
         """
         The `UpdateTimeToLive` method enables or disables Time to Live (TTL) for the
